@@ -38,7 +38,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.4.1"
+__version__ = "1.4.2"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_DateTime.git"
 
 # Constants
@@ -1521,11 +1521,11 @@ class datetime(date):
         self,
         year: Optional[int] = None,
         month: Optional[str] = None,
-        day: Optional[str] = None,
-        hour: Optional[str] = None,
-        minute: Optional[str] = None,
-        second: Optional[str] = None,
-        microsecond: Optional[str] = None,
+        day: Optional[int] = None,
+        hour: Optional[int] = None,
+        minute: Optional[int] = None,
+        second: Optional[int] = None,
+        microsecond: Optional[int] = None,
         tzinfo: bool = True,
         *,
         fold: Optional[int] = None,
